@@ -101,7 +101,6 @@ public abstract class AbstractJAXBProvider<T> extends AbstractConfigurableProvid
     protected Set<Class<?>> collectionContextClasses = ConcurrentHashMap.newKeySet();
 
     protected Map<String, String> jaxbElementClassMap = Collections.emptyMap();
-    protected Map<String, Boolean> objectFactoryOrIndexMap = new ConcurrentHashMap<>();
     protected boolean unmarshalAsJaxbElement;
     protected boolean marshalAsJaxbElement;
     protected boolean xmlTypeAsJaxbElementOnly;
@@ -595,15 +594,8 @@ public abstract class AbstractJAXBProvider<T> extends AbstractConfigurableProvid
     }
 
     protected boolean objectFactoryOrIndexAvailable(Class<?> type) {
-        if (this.objectFactoryOrIndexMap.get(type.getName()) != null) {
-            return this.objectFactoryOrIndexMap.get(type.getName());
-        } else {
-            boolean ret = type.getResource("ObjectFactory.class") != null
+        return type.getResource("ObjectFactory.class") != null
                || type.getResource("jaxb.index") != null;
-            this.objectFactoryOrIndexMap.put(type.getName(), ret);
-            return ret;
-        }
-        
     }
 
     private boolean objectFactoryForType(Type genericType) {
@@ -674,7 +666,7 @@ public abstract class AbstractJAXBProvider<T> extends AbstractConfigurableProvid
     }
 
     protected Class<?> getActualType(Class<?> type, Type genericType, Annotation[] anns) {
-        Class<?> theType = null;
+        Class<?> theType;
         if (JAXBElement.class.isAssignableFrom(type)) {
             theType = InjectionUtils.getActualType(genericType);
         } else {
@@ -712,7 +704,6 @@ public abstract class AbstractJAXBProvider<T> extends AbstractConfigurableProvid
     public void clearContexts() {
         classContexts.clear();
         packageContexts.clear();
-        objectFactoryOrIndexMap.clear();
     }
 
     //TODO: move these methods into the dedicated utility class
